==> ipxact-1685-2014-1.0-20260114.045943-1-sources.jar: org/accellera/IPXACT_1685_2014/ClockDriverType.java <==

package org.accellera.IPXACT_1685_2014;

import jakarta.annotation.Generated;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for clockDriverType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="clockDriverType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="clockPeriod"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
 *                 &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
 *                 &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="clockPulseOffset"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
 *                 &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
 *                 &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="clockPulseValue" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}unsignedBitVectorExpression"/&gt;
 *         &lt;element name="clockPulseDuration"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
 *                 &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
 *                 &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *       &lt;attGroup ref="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}id.att"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "clockDriverType", propOrder = {
    "clockPeriod",
    "clockPulseOffset",
    "clockPulseValue",
    "clockPulseDuration"
})
@XmlSeeAlso({
    OtherClockDriver.class,
    ClockDriver.class
})
@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
public class ClockDriverType {

    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    protected ClockDriverType.ClockPeriod clockPeriod;
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    protected ClockDriverType.ClockPulseOffset clockPulseOffset;
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    protected UnsignedBitVectorExpression clockPulseValue;
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    protected ClockDriverType.ClockPulseDuration clockPulseDuration;
    @XmlAttribute(name = "id", namespace = "http://www.w3.org/XML/1998/namespace")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    protected String id;

    /**
     * Gets the value of the clockPeriod property.
     * 
     * @return
     *     possible object is
     *     {@link ClockDriverType.ClockPeriod }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public ClockDriverType.ClockPeriod getClockPeriod() {
        return clockPeriod;
    }

    /**
     * Sets the value of the clockPeriod property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClockDriverType.ClockPeriod }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public void setClockPeriod(ClockDriverType.ClockPeriod value) {
        this.clockPeriod = value;
    }

    /**
     * Gets the value of the clockPulseOffset property.
     * 
     * @return
     *     possible object is
     *     {@link ClockDriverType.ClockPulseOffset }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public ClockDriverType.ClockPulseOffset getClockPulseOffset() {
        return clockPulseOffset;
    }

    /**
     * Sets the value of the clockPulseOffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClockDriverType.ClockPulseOffset }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public void setClockPulseOffset(ClockDriverType.ClockPulseOffset value) {
        this.clockPulseOffset = value;
    }

    /**
     * Gets the value of the clockPulseValue property.
     * 
     * @return
     *     possible object is
     *     {@link UnsignedBitVectorExpression }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public UnsignedBitVectorExpression getClockPulseValue() {
        return clockPulseValue;
    }

    /**
     * Sets the value of the clockPulseValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnsignedBitVectorExpression }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public void setClockPulseValue(UnsignedBitVectorExpression value) {
        this.clockPulseValue = value;
    }

    /**
     * Gets the value of the clockPulseDuration property.
     * 
     * @return
     *     possible object is
     *     {@link ClockDriverType.ClockPulseDuration }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public ClockDriverType.ClockPulseDuration getClockPulseDuration() {
        return clockPulseDuration;
    }

    /**
     * Sets the value of the clockPulseDuration property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClockDriverType.ClockPulseDuration }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public void setClockPulseDuration(ClockDriverType.ClockPulseDuration value) {
        this.clockPulseDuration = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public void setId(String value) {
        this.id = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
     *       &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
     *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public static class ClockPeriod
        extends RealExpression
    {

        @XmlAttribute(name = "units")
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        protected DelayValueUnitType units;

        /**
         * Gets the value of the units property.
         * 
         * @return
         *     possible object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        public DelayValueUnitType getUnits() {
            if (units == null) {
                return DelayValueUnitType.NS;
            } else {
                return units;
            }
        }

        /**
         * Sets the value of the units property.
         * 
         * @param value
         *     allowed object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        public void setUnits(DelayValueUnitType value) {
            this.units = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
     *       &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
     *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public static class ClockPulseDuration
        extends RealExpression
    {

        @XmlAttribute(name = "units")
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        protected DelayValueUnitType units;

        /**
         * Gets the value of the units property.
         * 
         * @return
         *     possible object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        public DelayValueUnitType getUnits() {
            if (units == null) {
                return DelayValueUnitType.NS;
            } else {
                return units;
            }
        }

        /**
         * Sets the value of the units property.
         * 
         * @param value
         *     allowed object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        public void setUnits(DelayValueUnitType value) {
            this.units = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
     *       &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
     *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
    public static class ClockPulseOffset
        extends RealExpression
    {

        @XmlAttribute(name = "units")
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        protected DelayValueUnitType units;

        /**
         * Gets the value of the units property.
         * 
         * @return
         *     possible object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        public DelayValueUnitType getUnits() {
            if (units == null) {
                return DelayValueUnitType.NS;
            } else {
                return units;
            }
        }

        /**
         * Sets the value of the units property.
         * 
         * @param value
         *     allowed object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:45Z")
        public void setUnits(DelayValueUnitType value) {
            this.units = value;
        }

    }

}

==> ipxact-1685-2014-1.0-20260114.045953-1-sources.jar: org/accellera/IPXACT_1685_2014/ClockDriverType.java <==

package org.accellera.IPXACT_1685_2014;

import javax.annotation.Generated;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for clockDriverType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="clockDriverType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="clockPeriod"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
 *                 &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
 *                 &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="clockPulseOffset"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
 *                 &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
 *                 &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="clockPulseValue" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}unsignedBitVectorExpression"/&gt;
 *         &lt;element name="clockPulseDuration"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
 *                 &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
 *                 &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *       &lt;attGroup ref="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}id.att"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "clockDriverType", propOrder = {
    "clockPeriod",
    "clockPulseOffset",
    "clockPulseValue",
    "clockPulseDuration"
})
@XmlSeeAlso({
    OtherClockDriver.class,
    ClockDriver.class
})
@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
public class ClockDriverType {

    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    protected ClockDriverType.ClockPeriod clockPeriod;
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    protected ClockDriverType.ClockPulseOffset clockPulseOffset;
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    protected UnsignedBitVectorExpression clockPulseValue;
    @XmlElement(required = true)
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    protected ClockDriverType.ClockPulseDuration clockPulseDuration;
    @XmlAttribute(name = "id", namespace = "http://www.w3.org/XML/1998/namespace")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    protected String id;

    /**
     * Gets the value of the clockPeriod property.
     * 
     * @return
     *     possible object is
     *     {@link ClockDriverType.ClockPeriod }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public ClockDriverType.ClockPeriod getClockPeriod() {
        return clockPeriod;
    }

    /**
     * Sets the value of the clockPeriod property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClockDriverType.ClockPeriod }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public void setClockPeriod(ClockDriverType.ClockPeriod value) {
        this.clockPeriod = value;
    }

    /**
     * Gets the value of the clockPulseOffset property.
     * 
     * @return
     *     possible object is
     *     {@link ClockDriverType.ClockPulseOffset }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public ClockDriverType.ClockPulseOffset getClockPulseOffset() {
        return clockPulseOffset;
    }

    /**
     * Sets the value of the clockPulseOffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClockDriverType.ClockPulseOffset }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public void setClockPulseOffset(ClockDriverType.ClockPulseOffset value) {
        this.clockPulseOffset = value;
    }

    /**
     * Gets the value of the clockPulseValue property.
     * 
     * @return
     *     possible object is
     *     {@link UnsignedBitVectorExpression }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public UnsignedBitVectorExpression getClockPulseValue() {
        return clockPulseValue;
    }

    /**
     * Sets the value of the clockPulseValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link UnsignedBitVectorExpression }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public void setClockPulseValue(UnsignedBitVectorExpression value) {
        this.clockPulseValue = value;
    }

    /**
     * Gets the value of the clockPulseDuration property.
     * 
     * @return
     *     possible object is
     *     {@link ClockDriverType.ClockPulseDuration }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public ClockDriverType.ClockPulseDuration getClockPulseDuration() {
        return clockPulseDuration;
    }

    /**
     * Sets the value of the clockPulseDuration property.
     * 
     * @param value
     *     allowed object is
     *     {@link ClockDriverType.ClockPulseDuration }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public void setClockPulseDuration(ClockDriverType.ClockPulseDuration value) {
        this.clockPulseDuration = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public void setId(String value) {
        this.id = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
     *       &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
     *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public static class ClockPeriod
        extends RealExpression
    {

        @XmlAttribute(name = "units")
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        protected DelayValueUnitType units;

        /**
         * Gets the value of the units property.
         * 
         * @return
         *     possible object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        public DelayValueUnitType getUnits() {
            if (units == null) {
                return DelayValueUnitType.NS;
            } else {
                return units;
            }
        }

        /**
         * Sets the value of the units property.
         * 
         * @param value
         *     allowed object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        public void setUnits(DelayValueUnitType value) {
            this.units = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
     *       &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
     *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public static class ClockPulseDuration
        extends RealExpression
    {

        @XmlAttribute(name = "units")
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        protected DelayValueUnitType units;

        /**
         * Gets the value of the units property.
         * 
         * @return
         *     possible object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        public DelayValueUnitType getUnits() {
            if (units == null) {
                return DelayValueUnitType.NS;
            } else {
                return units;
            }
        }

        /**
         * Sets the value of the units property.
         * 
         * @param value
         *     allowed object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        public void setUnits(DelayValueUnitType value) {
            this.units = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.accellera.org/XMLSchema/IPXACT/1685-2014&gt;realExpression"&gt;
     *       &lt;attribute name="units" type="{http://www.accellera.org/XMLSchema/IPXACT/1685-2014}delayValueUnitType" default="ns" /&gt;
     *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
    public static class ClockPulseOffset
        extends RealExpression
    {

        @XmlAttribute(name = "units")
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        protected DelayValueUnitType units;

        /**
         * Gets the value of the units property.
         * 
         * @return
         *     possible object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        public DelayValueUnitType getUnits() {
            if (units == null) {
                return DelayValueUnitType.NS;
            } else {
                return units;
            }
        }

        /**
         * Sets the value of the units property.
         * 
         * @param value
         *     allowed object is
         *     {@link DelayValueUnitType }
         *     
         */
        @Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v3.0.2", date = "2026-01-14T04:58:49Z")
        public void setUnits(DelayValueUnitType value) {
            this.units = value;
        }

    }

}
